"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const formatter_1 = require("./response/formatter");
const error_1 = require("./response/error");
class Response {
    constructor(formatters = []) {
        this.formatters = formatters;
        this.data = {};
    }
    get hasErrorStatusCode() {
        const { statusCode } = this.data;
        return statusCode && !!error_1.ErrorStatuses[statusCode];
    }
    status(statusCode) {
        this.data.statusCode = statusCode;
        return this;
    }
    header(name, value) {
        if (!this.data.headers) {
            this.data.headers = {};
        }
        this.data.headers[name] = value;
        return this;
    }
    error(status, body) {
        this.status(status).send(body);
    }
    send(body) {
        if (body) {
            this.data.body = body;
        }
    }
    format() {
        return this.formatters.reduce((previous, formatter) => {
            const current = formatter(this.data);
            current.headers = Object.assign({}, previous.headers, current.headers);
            return Object.assign(previous, current);
        }, formatter_1.defaultFormatter(this.data));
    }
}
exports.Response = Response;
